@@ -2,7 +2,7 @@
 # @Author: Kelvin
 # @Date:   2021-02-11 12:22:40
 # @Last Modified by:   Kelvin
-# @Last Modified time: 2021-08-13 13:30:02
+# @Last Modified time: 2021-08-17 20:25:22
 
 import os
 from collections import defaultdict
@@ -301,8 +301,7 @@ class Dandelion:
         # now to actually saving
         data = self.data.copy()
         data = sanitize_data(data)
-        sanitize_dtype(data)
-
+        data = sanitize_data_for_saving(data)
         data.to_hdf(filename,
                     "data",
                     complib=comp,
@@ -436,22 +435,30 @@ class Query:
                         query + '_VDJ':
                         np.sum([float(x) for x in vdj if present(x)])
                     })
+                else:
+                    cols.update({query + 'VDJ': np.nan})
                 if len(vj) > 0:
                     cols.update({
                         query + '_VJ':
                         np.sum([float(x) for x in vj if present(x)])
                     })
+                else:
+                    cols.update({query + 'VJ': np.nan})
             elif retrieve_mode == 'split and average':
                 if len(vdj) > 0:
                     cols.update({
                         query + '_VDJ':
                         np.mean([float(x) for x in vdj if present(x)])
                     })
+                else:
+                    cols.update({query + '_VDJ': np.nan})
                 if len(vj) > 0:
                     cols.update({
                         query + '_VJ':
                         np.mean([float(x) for x in vj if present(x)])
                     })
+                else:
+                    cols.update({query + '_VJ': np.nan})
             elif retrieve_mode == 'merge':
                 cols.update(
                     {query: '|'.join(x for x in set(vdj + vj) if present(x))})
@@ -467,15 +474,26 @@ class Query:
                     query:
                     np.sum([float(x) for x in vdj + vj if present(x)])
                 })
+                if not present(cols[query]):
+                    cols.update({query: np.nan})
             elif retrieve_mode == 'average':
                 cols.update({
                     query:
                     np.mean([float(x) for x in vdj + vj if present(x)])
                 })
+                if not present(cols[query]):
+                    cols.update({query: np.nan})
             ret.update({cell: cols})
         out = pd.DataFrame.from_dict(ret, orient='index')
-        if self.querydtype == 'object':
-            out.fillna('', inplace=True)
+        if retrieve_mode not in ['split and sum', 'split and average', 'sum', 'average']:
+            if retrieve_mode == 'split':
+                for x in out:
+                    try:
+                        out[x] = pd.to_numeric(out[x])
+                    except:
+                        out[x].fillna('', inplace=True)
+            else:
+                out.fillna('', inplace=True)
         return (out)
 
 
@@ -975,6 +993,8 @@ def update_metadata(self: Dandelion,
             retrieve = [retrieve]
         if type(retrieve_mode) is str:
             retrieve_mode = [retrieve_mode]
+            if len(retrieve) > len(retrieve_mode):
+                retrieve_mode = [x for x in retrieve_mode for i in retrieve]
         for ret, mode in zip(retrieve, retrieve_mode):
             ret_dict.update({ret: {
                 'query': ret,
@@ -991,6 +1011,10 @@ def update_metadata(self: Dandelion,
                 raise KeyError(
                     'Cannot retrieve \'%s\' : Unknown column name.' % k)
         ret_metadata = pd.concat(retrieve_.values(), axis=1, join="inner")
+        ret_metadata.dropna(axis = 1, how = 'all', inplace = True)
+        for col in ret_metadata:
+            if all_missing(ret_metadata[col]):
+                ret_metadata.drop(col, axis = 1, inplace = True)
 
         if collapse_alleles:
             for k in ret_dict.keys():
